# 貢獻者公約

## 我們的承諾

為了營造一個開放且友善的環境，我們作為貢獻者和維護者承諾：無論年齡、體型、殘疾、種族、性別認同和表達、經驗水平、國籍、個人外表、種族、宗教或性認同和性取向如何，參與我們專案和社群的每個人都不會受到騷擾。

## 我們的標準

有助於創造正面環境的行為包括：

- 使用歡迎和包容的語言
- 尊重不同的觀點和經驗
- 優雅地接受建設性批評
- 關注對社群最有利的事情
- 對其他社群成員表示同理心

不可接受的行為包括：

- 使用性暗示的語言或圖像
- 挑釁、侮辱或貶損性評論，以及人身或政治攻擊
- 公開或私下騷擾
- 未經明確許可發布他人私人資訊
- 其他在專業環境中被認為不適當的行為

## 我們的責任

專案維護者有責任澄清可接受行為的標準，並應對任何不可接受的行為採取適當且公平的糾正措施。

## 執行

如遇到辱罵、騷擾或其他不可接受的行為，可向專案團隊報告。所有投訴都將被審查和調查，並將作出必要且適當的回應。

## 歸屬

本行為準則改編自 [Contributor Covenant](https://www.contributor-covenant.org)，版本 2.1。
